#!/usr/bin/env python

"""Tests for `vulcan_athena` package."""

import pytest

from vulcan_athena import vulcan_athena


@pytest.fixture
def response():
    """Sample pytest fixture.

    See more at: http://doc.pytest.org/en/latest/fixture.html
    """
    # import requests
    # return requests.get('https://github.com/audreyr/cookiecutter-pypackage')


def test_content(response):
    """Sample pytest test function with the pytest fixture as an argument."""
    # from bs4 import BeautifulSoup
    # assert 'GitHub' in BeautifulSoup(response.content).title.string


def test_sqrt_with_param():
    assert vulcan_athena.sqrt_function(25) == 5
